summaryrefslogtreecommitdiffstats
path: root/kicker/kicker
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/kicker')
-rw-r--r--kicker/kicker/CMakeLists.txt8
-rw-r--r--kicker/kicker/Makefile.am8
-rw-r--r--kicker/kicker/buttons/browserbutton.cpp4
-rw-r--r--kicker/kicker/buttons/desktopbutton.cpp2
-rw-r--r--kicker/kicker/buttons/extensionbutton.cpp2
-rw-r--r--kicker/kicker/buttons/nonkdeappbutton.cpp2
-rw-r--r--kicker/kicker/buttons/servicemenubutton.cpp2
-rw-r--r--kicker/kicker/buttons/urlbutton.cpp2
-rw-r--r--kicker/kicker/core/container_applet.cpp2
-rw-r--r--kicker/kicker/core/container_base.cpp2
-rw-r--r--kicker/kicker/core/container_button.cpp2
-rw-r--r--kicker/kicker/core/container_extension.cpp2
-rw-r--r--kicker/kicker/core/containerarea.cpp2
-rw-r--r--kicker/kicker/core/extensionmanager.cpp6
-rw-r--r--kicker/kicker/core/kicker.cpp2
-rw-r--r--kicker/kicker/core/main.cpp2
-rw-r--r--kicker/kicker/core/panelextension.cpp2
-rw-r--r--kicker/kicker/kcmkicker.desktop2
-rw-r--r--kicker/kicker/kicker-3.4-reverseLayout.cpp10
-rwxr-xr-xkicker/kicker/kicker-3.5-tdeconfigXTize.pl (renamed from kicker/kicker/kicker-3.5-kconfigXTize.pl)0
-rw-r--r--kicker/kicker/kickerrc.upd4
-rw-r--r--kicker/kicker/ui/browser_dlg.cpp2
-rw-r--r--kicker/kicker/ui/browser_mnu.cpp6
-rw-r--r--kicker/kicker/ui/itemview.cpp2
-rw-r--r--kicker/kicker/ui/k_mnu.cpp2
-rw-r--r--kicker/kicker/ui/k_new_mnu.cpp12
-rw-r--r--kicker/kicker/ui/service_mnu.cpp2
27 files changed, 47 insertions, 47 deletions
diff --git a/kicker/kicker/CMakeLists.txt b/kicker/kicker/CMakeLists.txt
index 313187cee..ce4befcae 100644
--- a/kicker/kicker/CMakeLists.txt
+++ b/kicker/kicker/CMakeLists.txt
@@ -30,12 +30,12 @@ link_directories( ${TQT_LIBRARY_DIRS} )
install( FILES panel.desktop DESTINATION ${AUTOSTART_INSTALL_DIR} )
install( FILES kcmkicker.desktop DESTINATION ${XDG_APPS_INSTALL_DIR} )
-install( FILES kickerrc.upd DESTINATION ${DATA_INSTALL_DIR}/kconf_update )
+install( FILES kickerrc.upd DESTINATION ${DATA_INSTALL_DIR}/tdeconf_update )
install( PROGRAMS
kicker-3.1-properSizeSetting.pl kicker-3.5-taskbarEnums.pl
- kicker-3.5-kconfigXTize.pl
- DESTINATION ${DATA_INSTALL_DIR}/kconf_update )
+ kicker-3.5-tdeconfigXTize.pl
+ DESTINATION ${DATA_INSTALL_DIR}/tdeconf_update )
##### kicker-3.4-reverseLayout (executable) #####
@@ -43,7 +43,7 @@ install( PROGRAMS
tde_add_executable( kicker-3.4-reverseLayout
SOURCES kicker-3.4-reverseLayout.cpp
LINK tdecore-shared
- DESTINATION ${LIB_INSTALL_DIR}/kconf_update_bin
+ DESTINATION ${LIB_INSTALL_DIR}/tdeconf_update_bin
)
diff --git a/kicker/kicker/Makefile.am b/kicker/kicker/Makefile.am
index cf22b5c70..c97d61f60 100644
--- a/kicker/kicker/Makefile.am
+++ b/kicker/kicker/Makefile.am
@@ -28,14 +28,14 @@ messages: rc.cpp
dummy.cpp:
echo > $@
-kconf_PROGRAMS = kicker-3.4-reverseLayout
-kconfdir = $(libdir)/kconf_update_bin
+tdeconf_PROGRAMS = kicker-3.4-reverseLayout
+tdeconfdir = $(libdir)/tdeconf_update_bin
kicker_3_4_reverseLayout_SOURCES = kicker-3.4-reverseLayout.cpp
kicker_3_4_reverseLayout_LDADD = $(LIB_QT) $(LIB_TDECORE)
kicker_3_4_reverseLayout_LDFLAGS = $(all_libraries)
-updatedir = $(kde_datadir)/kconf_update
+updatedir = $(kde_datadir)/tdeconf_update
update_DATA = kickerrc.upd
-update_SCRIPTS = kicker-3.1-properSizeSetting.pl kicker-3.5-taskbarEnums.pl kicker-3.5-kconfigXTize.pl
+update_SCRIPTS = kicker-3.1-properSizeSetting.pl kicker-3.5-taskbarEnums.pl kicker-3.5-tdeconfigXTize.pl
diff --git a/kicker/kicker/buttons/browserbutton.cpp b/kicker/kicker/buttons/browserbutton.cpp
index e470fb93a..36d650271 100644
--- a/kicker/kicker/buttons/browserbutton.cpp
+++ b/kicker/kicker/buttons/browserbutton.cpp
@@ -25,10 +25,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqtooltip.h>
#include <tqdragobject.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <klocale.h>
#include <konq_operations.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
#include "kicker.h"
#include "browser_mnu.h"
diff --git a/kicker/kicker/buttons/desktopbutton.cpp b/kicker/kicker/buttons/desktopbutton.cpp
index c35a8bf47..dc6063c2b 100644
--- a/kicker/kicker/buttons/desktopbutton.cpp
+++ b/kicker/kicker/buttons/desktopbutton.cpp
@@ -27,7 +27,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <klocale.h>
#include <kglobalsettings.h>
#include <konq_operations.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
#include "showdesktop.h"
#include "kicker.h"
diff --git a/kicker/kicker/buttons/extensionbutton.cpp b/kicker/kicker/buttons/extensionbutton.cpp
index 8ab9fd0bd..f45a61a4b 100644
--- a/kicker/kicker/buttons/extensionbutton.cpp
+++ b/kicker/kicker/buttons/extensionbutton.cpp
@@ -23,7 +23,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqtooltip.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kpanelmenu.h>
#include "menuinfo.h"
diff --git a/kicker/kicker/buttons/nonkdeappbutton.cpp b/kicker/kicker/buttons/nonkdeappbutton.cpp
index e48386008..016c75aee 100644
--- a/kicker/kicker/buttons/nonkdeappbutton.cpp
+++ b/kicker/kicker/buttons/nonkdeappbutton.cpp
@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqtooltip.h>
#include <tqdragobject.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdesktopfile.h>
#include <kapplication.h>
#include <kglobal.h>
diff --git a/kicker/kicker/buttons/servicemenubutton.cpp b/kicker/kicker/buttons/servicemenubutton.cpp
index 0ebc931f4..a15ba1cf1 100644
--- a/kicker/kicker/buttons/servicemenubutton.cpp
+++ b/kicker/kicker/buttons/servicemenubutton.cpp
@@ -23,7 +23,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqtooltip.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kservicegroup.h>
#include <klocale.h>
diff --git a/kicker/kicker/buttons/urlbutton.cpp b/kicker/kicker/buttons/urlbutton.cpp
index 132aa8193..ac9934b33 100644
--- a/kicker/kicker/buttons/urlbutton.cpp
+++ b/kicker/kicker/buttons/urlbutton.cpp
@@ -25,7 +25,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqfile.h>
#include <kdesktopfile.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
#include <konq_operations.h>
#include <kicontheme.h>
#include <kglobal.h>
diff --git a/kicker/kicker/core/container_applet.cpp b/kicker/kicker/core/container_applet.cpp
index a35b34fd0..d3d7f10ba 100644
--- a/kicker/kicker/core/container_applet.cpp
+++ b/kicker/kicker/core/container_applet.cpp
@@ -32,7 +32,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <dcopclient.h>
#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
#include <klocale.h>
diff --git a/kicker/kicker/core/container_base.cpp b/kicker/kicker/core/container_base.cpp
index 56c09f285..1efafe801 100644
--- a/kicker/kicker/core/container_base.cpp
+++ b/kicker/kicker/core/container_base.cpp
@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqpopupmenu.h>
#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include "global.h"
diff --git a/kicker/kicker/core/container_button.cpp b/kicker/kicker/core/container_button.cpp
index 30c31401d..8196127e9 100644
--- a/kicker/kicker/core/container_button.cpp
+++ b/kicker/kicker/core/container_button.cpp
@@ -26,7 +26,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqlayout.h>
#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
#include <tdemultipledrag.h>
diff --git a/kicker/kicker/core/container_extension.cpp b/kicker/kicker/core/container_extension.cpp
index 7639fe146..d2f2982b7 100644
--- a/kicker/kicker/core/container_extension.cpp
+++ b/kicker/kicker/core/container_extension.cpp
@@ -38,7 +38,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqcolor.h>
#include <dcopclient.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kdesktopfile.h>
#include <kglobal.h>
diff --git a/kicker/kicker/core/containerarea.cpp b/kicker/kicker/core/containerarea.cpp
index 12949f95b..c42ffc13a 100644
--- a/kicker/kicker/core/containerarea.cpp
+++ b/kicker/kicker/core/containerarea.cpp
@@ -45,7 +45,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <krootpixmap.h>
#include <kpixmap.h>
#include <klocale.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
#include <kservice.h>
#include <kurldrag.h>
diff --git a/kicker/kicker/core/extensionmanager.cpp b/kicker/kicker/core/extensionmanager.cpp
index 62594443f..893cb1665 100644
--- a/kicker/kicker/core/extensionmanager.cpp
+++ b/kicker/kicker/core/extensionmanager.cpp
@@ -27,10 +27,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <stdlib.h>
#include <kaboutdata.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
#include <klocale.h>
#include <kmenubar.h>
#include <kmessagebox.h>
@@ -233,7 +233,7 @@ void ExtensionManager::migrateMenubar()
// will have a menubar in it, and if so, abort creating one of our
// own.
//
- // the reason i didn't do this as a kconfig_update script is that
+ // the reason i didn't do this as a tdeconfig_update script is that
// most people don't use this feature, so no reason to penalize
// everyone, and moreover the user may added this to their main
// panel, meaning kickerrc itself would have to be vastly modified
diff --git a/kicker/kicker/core/kicker.cpp b/kicker/kicker/core/kicker.cpp
index 3fa04e374..0521e6413 100644
--- a/kicker/kicker/core/kicker.cpp
+++ b/kicker/kicker/core/kicker.cpp
@@ -29,7 +29,7 @@
#include <tqtooltip.h>
#include <dcopclient.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kcmdlineargs.h>
#include <kcmultidialog.h>
#include <kcrash.h>
diff --git a/kicker/kicker/core/main.cpp b/kicker/kicker/core/main.cpp
index 17a148474..e6c5ba842 100644
--- a/kicker/kicker/core/main.cpp
+++ b/kicker/kicker/core/main.cpp
@@ -27,7 +27,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kdebug.h>
#include <kaboutdata.h>
#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <dcopclient.h>
#include <dcopref.h>
diff --git a/kicker/kicker/core/panelextension.cpp b/kicker/kicker/core/panelextension.cpp
index 6b41f1c50..fbf6b9e43 100644
--- a/kicker/kicker/core/panelextension.cpp
+++ b/kicker/kicker/core/panelextension.cpp
@@ -34,7 +34,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kglobal.h>
#include <kpopupmenu.h>
#include <kiconloader.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kstdguiitem.h>
#include "container_applet.h"
diff --git a/kicker/kicker/kcmkicker.desktop b/kicker/kicker/kcmkicker.desktop
index 929871123..348ed746e 100644
--- a/kicker/kicker/kcmkicker.desktop
+++ b/kicker/kicker/kcmkicker.desktop
@@ -1,7 +1,7 @@
[Desktop Entry]
Icon=kcmkicker
Type=Application
-Exec=kcmshell %i kicker_config kcmtaskbar
+Exec=tdecmshell %i kicker_config kcmtaskbar
Name=Configure the Panel
Name[af]=Stel die paneel op
Name[ar]=قم بإعداد اللوحة
diff --git a/kicker/kicker/kicker-3.5-kconfigXTize.pl b/kicker/kicker/kicker-3.5-tdeconfigXTize.pl
index e836116d7..e836116d7 100755
--- a/kicker/kicker/kicker-3.5-kconfigXTize.pl
+++ b/kicker/kicker/kicker-3.5-tdeconfigXTize.pl
diff --git a/kicker/kicker/kickerrc.upd b/kicker/kicker/kickerrc.upd
index 282a52cb1..5b82f9e2c 100644
--- a/kicker/kicker/kickerrc.upd
+++ b/kicker/kicker/kickerrc.upd
@@ -14,9 +14,9 @@ Group=General
Options=overwrite
Script=kicker-3.5-taskbarEnums.pl,perl
-Id=kde_3_5_kconfigXTize
+Id=kde_3_5_tdeconfigXTize
File=kickerrc
Group=menus
-Script=kicker-3.5-kconfigXTize.pl,perl
+Script=kicker-3.5-tdeconfigXTize.pl,perl
RemoveKey=DetailedEntriesNamesFirst
RemoveKey=DetailedMenuEntries
diff --git a/kicker/kicker/ui/browser_dlg.cpp b/kicker/kicker/ui/browser_dlg.cpp
index 6aa246eb6..3ebe095dc 100644
--- a/kicker/kicker/ui/browser_dlg.cpp
+++ b/kicker/kicker/ui/browser_dlg.cpp
@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kglobal.h>
#include <klocale.h>
#include <kicondialog.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
#include <klineedit.h>
#include <kmessagebox.h>
diff --git a/kicker/kicker/ui/browser_mnu.cpp b/kicker/kicker/ui/browser_mnu.cpp
index c6ca4ab32..9aa352500 100644
--- a/kicker/kicker/ui/browser_mnu.cpp
+++ b/kicker/kicker/ui/browser_mnu.cpp
@@ -28,12 +28,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kdebug.h>
#include <kdesktopfile.h>
#include <kdirwatch.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
#include <kglobal.h>
#include <kglobalsettings.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kiconloader.h>
-#include <kio/global.h>
+#include <tdeio/global.h>
#include <klocale.h>
#include <kmimetype.h>
#include <konq_operations.h>
diff --git a/kicker/kicker/ui/itemview.cpp b/kicker/kicker/ui/itemview.cpp
index 3d33a825a..ee82bc91f 100644
--- a/kicker/kicker/ui/itemview.cpp
+++ b/kicker/kicker/ui/itemview.cpp
@@ -50,7 +50,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kpixmapeffect.h>
#include <kaction.h>
#include <kbookmarkmenu.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
#include <kglobalsettings.h>
diff --git a/kicker/kicker/ui/k_mnu.cpp b/kicker/kicker/ui/k_mnu.cpp
index 84c977331..eb87f02d0 100644
--- a/kicker/kicker/ui/k_mnu.cpp
+++ b/kicker/kicker/ui/k_mnu.cpp
@@ -40,7 +40,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kaboutkde.h>
#include <kaction.h>
#include <kbookmarkmenu.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
#include <kglobalsettings.h>
diff --git a/kicker/kicker/ui/k_new_mnu.cpp b/kicker/kicker/ui/k_new_mnu.cpp
index 6f2c4eacb..f5bf25471 100644
--- a/kicker/kicker/ui/k_new_mnu.cpp
+++ b/kicker/kicker/ui/k_new_mnu.cpp
@@ -48,7 +48,7 @@
#include <kaboutkde.h>
#include <kaction.h>
#include <kbookmarkmenu.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
#include <kglobalsettings.h>
@@ -70,8 +70,8 @@
#include <kbookmarkmanager.h>
#include <kbookmark.h>
#include <kprocess.h>
-#include <kio/jobclasses.h>
-#include <kio/job.h>
+#include <tdeio/jobclasses.h>
+#include <tdeio/job.h>
#include <dcopref.h>
#include <konq_popupmenu.h>
#include <konqbookmarkmanager.h>
@@ -3512,16 +3512,16 @@ bool KMenu::ensureServiceRunning(const TQString & service)
TQDataStream arg(data, IO_WriteOnly);
arg << service << URLs;
- if ( !kapp->dcopClient()->call( "klauncher", "klauncher", "start_service_by_desktop_name(TQString,TQStringList)",
+ if ( !kapp->dcopClient()->call( "tdelauncher", "tdelauncher", "start_service_by_desktop_name(TQString,TQStringList)",
data, replyType, replyData) ) {
- tqWarning( "call to klauncher failed.");
+ tqWarning( "call to tdelauncher failed.");
return false;
}
TQDataStream reply(replyData, IO_ReadOnly);
if ( replyType != "serviceResult" )
{
- tqWarning( "unexpected result '%s' from klauncher.", replyType.data());
+ tqWarning( "unexpected result '%s' from tdelauncher.", replyType.data());
return false;
}
int result;
diff --git a/kicker/kicker/ui/service_mnu.cpp b/kicker/kicker/ui/service_mnu.cpp
index 1e77a1731..dfe3f4433 100644
--- a/kicker/kicker/ui/service_mnu.cpp
+++ b/kicker/kicker/ui/service_mnu.cpp
@@ -44,7 +44,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tdesycocaentry.h>
#include <kservice.h>
#include <kurldrag.h>
-#include <kio/job.h>
+#include <tdeio/job.h>
#include "global.h"
#include "kicker.h"
diff --git a/kicker/kicker/kicker-3.4-reverseLayout.cpp b/kicker/kicker/kicker-3.4-reverseLayout.cpp
index a588c6258..9491e7d41 100644
--- a/kicker/kicker/kicker-3.4-reverseLayout.cpp
+++ b/kicker/kicker/kicker-3.4-reverseLayout.cpp
@@ -130,7 +130,7 @@ int main(int argc, char** argv)
if (!childPanelConfigFiles.isEmpty())
{
// Create a temporary kconf_update .upd file for updating the childpanels
KTempFile tempFile(TQString::null, ".upd");
TQTextStream* upd = tempFile.textStream();
for (it = childPanelConfigFiles.begin(); it != childPanelConfigFiles.end(); ++it)
@@ -142,10 +142,10 @@ int main(int argc, char** argv)
}
tempFile.close();
- // Run kconf_update on the childpanel config files.
- TDEProcess kconf_update;
- kconf_update << "kconf_update" << tempFile.name();
- kconf_update.start(TDEProcess::Block);
+ // Run tdeconf_update on the childpanel config files.
+ TDEProcess tdeconf_update;
+ tdeconf_update << "tdeconf_update" << tempFile.name();
+ tdeconf_update.start(TDEProcess::Block);
tempFile.unlink();
}
@@ -130,7 +130,7 @@ int main(int argc, char** argv)
if (!childPanelConfigFiles.isEmpty())
{
- // Create a temporary kconf_update .upd file for updating the childpanels
+ // Create a temporary tdeconf_update .upd file for updating the childpanels
KTempFile tempFile(TQString::null, ".upd");
TQTextStream* upd = tempFile.textStream();